@@ -2,8 +2,12 @@
 #'
 #' @description This score is calculated on the basis of Peak test, which is used for checking for homoscedasticity of residuals in regression analyses.
 #'
-#' @param object An object of class 'explainer' created with function \code{\link[DALEX]{explain}} from the DALEX package.
+#' @param object An object of class \code{explainer} created with function \code{\link[DALEX]{explain}} from the DALEX package.
 #' @param variable Name of model variable to order residuals.
+#' @param data New data that will be used to calcuate the score. Pass \code{NULL} if you want to use \code{data} from \code{object}.
+#' @param ... Other arguments dependent on the type of score.
+#'
+#' @return An object of class \code{auditor_score}.
 #'
 #' @examples
 #' dragons <- DALEX::dragons[1:100, ]
@@ -19,13 +23,15 @@
 #'
 #' @importFrom stats update rstandard predict pf sd
 #'
-#' @return an object of class 'auditor_score'
 #'
 #' @export
 
-score_peak <- function(object, variable = NULL){
+score_peak <- function(object, variable = NULL, data = NULL, ...) {
   if(!("explainer" %in% class(object))) stop("The function requires an object created with explain() function from the DALEX package.")
 
+  # inject new data to the explainer
+  if (!is.null(data)) object$data <- data
+
   std_res <- object$residuals / sd(object$residuals)
   peaks <- sum( (abs(std_res) >= cummax(abs(std_res)))) / length(object$y)
 
