@@ -2,9 +2,11 @@
 #'
 #' @description The area over the Regression Receiver Operating Characteristic.
 #'
-#' @param object An object of class 'explainer' created with function \code{\link[DALEX]{explain}} from the DALEX package.
+#' @param object An object of class \code{explainer} created with function \code{\link[DALEX]{explain}} from the DALEX package.
+#' @param data New data that will be used to calcuate the score. Pass \code{NULL} if you want to use \code{data} from \code{object}.
+#' @param ... Other arguments dependent on the type of score.
 #'
-#' @return an object of class 'score_audit'.
+#' @return An object of class \code{auditor_score}.
 #'
 #' @examples
 #' dragons <- DALEX::dragons[1:100, ]
@@ -28,9 +30,12 @@
 #' @export
 
 
-score_rroc <- function(object) {
+score_rroc <- function(object, data = NULL, ...) {
   if(!("explainer" %in% class(object))) stop("The function requires an object created with explain() function from the DALEX package.")
 
+  # inject new data to the explainer
+  if (!is.null(data)) object$data <- data
+
   object <- model_residual(object)
 
   RROCF <- make_rroc_df(object)
